@@ -1,24 +1,22 @@
-# 
+#
 # This file is part of Audio-MPD-Common
-# 
+#
 # This software is copyright (c) 2007 by Jerome Quelin.
-# 
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use 5.008;
 use warnings;
 use strict;
 
 package Audio::MPD::Common::Types;
-our $VERSION = '1.093190';
-
-
+{
+  $Audio::MPD::Common::Types::VERSION = '1.120880';
+}
 # ABSTRACT: types used in the distribution
 
 use Moose::Util::TypeConstraints;
-use Sub::Exporter;
-use Sub::Exporter -setup => { exports => [ qw{ State } ] };
 
 use Audio::MPD::Common::Time;
 
@@ -28,7 +26,6 @@ coerce 'Audio::MPD::Common::Time'
     => from 'Str'
     => via { Audio::MPD::Common::Time->new(time=>$_) };
 
-
 1;
 
 
@@ -40,15 +37,14 @@ Audio::MPD::Common::Types - types used in the distribution
 
 =head1 VERSION
 
-version 1.093190
+version 1.120880
 
 =head1 DESCRIPTION
 
 This module implements the specific types used by the distribution, and
-exports them. It is using L<Sub::Exporter> underneath, so you can use
-all the shenanigans to change the export names.
+exports them (exporting is done by L<Moose::Util::TypeConstraints>).
 
-Current types defined and exported:
+Current types defined:
 
 =over 4
 
@@ -61,7 +57,7 @@ It also defines a type coertion from C<Str> to C<Audio::MPD::Common::Time>.
 
 =head1 AUTHOR
 
-  Jerome Quelin
+Jerome Quelin
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -73,4 +69,5 @@ the same terms as the Perl 5 programming language system itself.
 =cut
 
 
-__END__
\ No newline at end of file
+__END__
+
